@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Request failed, network connection unavailable!" : "Pyyntö epäonnistui, yhteys ei ole käytettävissä!",
     "Request unauthorized. Are you logged in?" : "Pyyntö ei ole valtutettu. Oletko sisäänkirjautuneena?",
+    "Request forbidden. Are you an administrator?" : "Pyyntö ei ole valtuutettu. Oletko ylläpitäjä?",
     "Token expired or app not enabled! Reload the page!" : "Valtuutus vanheni tai sovellus ei ole käytössä! Lataa sivu uudelleen!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Sisäinen palvelinvirhe! Tarkista lisätiedot lokitiedostosta data/nextcloud.log!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Pyyntö epäonnistui, Nextcloud on parhaillaan ylläpitotilassa!",
@@ -10,13 +11,13 @@ OC.L10N.register(
     "Unread articles" : "Lukemattomat artikkelit",
     "News" : "Uutiset",
     "News folders" : "Syötekansiot",
+    "News articles" : "Uutisartikkelit",
     "Shared with me" : "Jaettu kanssasi",
     "An RSS/Atom feed reader" : "RSS-/Atom-syötteiden lukija",
     "Use system cron for updates" : "Käytä järjestelmän cronia päivityksille",
     "Disable this if you use a custom updater." : "Poista tämä käytöstä, jos käytät erillistä päivitintä.",
-    "Purge interval" : "Hävitysväli",
-    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Minimiaika sekunteina jonka jälkeen poistetut syötteet ja kansiot poistetaan tietokannasta; alle 60 sekuntin arvot ohitetaan.",
     "Maximum read count per feed" : "Syötekohtainen lukukertojen enimmäismäärä",
+    "Delete unread articles automatically" : "Poista lukemattomat artikkelit automaattisesti",
     "Maximum redirects" : "Uudelleenohjausten enimmäismäärä",
     "How many redirects the feed fetcher should follow." : "Kuinka montaa uudelleenohjausta syötteen noutajan tulisi seurata.",
     "Feed fetcher timeout" : "Syötteen hakemisen aikakatkaisu",
