@@ -7,16 +7,22 @@ OC.L10N.register(
     "Token expired or app not enabled! Reload the page!" : "Pasibaigė prieigos raktų galiojimas arba programėlė nėra įjungta! Įkelkite puslapį iš naujo!",
     "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Vidinė serverio klaida! Išsamesnei informacijai, žiūrėkite „data/nextcloud.log“ failą!",
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Užklausa nepavyko, Nextcloud šiuo metu yra techninės priežiūros veiksenoje!",
+    "News feeds" : "Naujienų kanalai",
     "Unread articles" : "Neskaityti straipsniai",
     "News" : "Naujienos",
     "News folders" : "Naujienų aplankai",
+    "News articles" : "Naujienų straipsniai",
     "An RSS/Atom feed reader" : "RSS/Atom kanalų skaitytuvė",
     "Use system cron for updates" : "Atnaujinimams naudoti sistemos planuoklę (cron)",
     "Maximum read count per feed" : "Didžiausias kanalo straipsnių kiekis",
+    "Delete unread articles automatically" : "Automatiškai ištrinti neskaitytus straipsnius",
+    "Enable this if you also want to delete unread articles." : "Įjunkite, jei tuo pačiu norite ištrinti neskaitytus straipsnius.",
     "Maximum redirects" : "Daugiausiai peradresavimų",
     "How many redirects the feed fetcher should follow." : "Kiek kartų kanalų gaviklis turėtų sekti paskui peradresavimus.",
     "Feed fetcher timeout" : "Kanalų gavimui skirtas laikas",
     "Explore Service URL" : "Išžvalgymo paslaugos URL",
+    "Successfully updated news configuration" : "Naujienų konfigūracija sėkmingai atnaujinta",
+    "Unable to update news config" : "Nepavyko atnaujinti naujienų konfigūracijos",
     "Download" : "Atsisiųsti",
     "Close" : "Užverti",
     "Subscribe to" : "Prenumeruoti",
