@@ -76,8 +76,8 @@ OC.L10N.register(
     "Pin to top" : "Закріпити нагорі",
     "Newest first" : "Новіші спочатку",
     "Oldest first" : "Старіші спочатку",
-    "Enable full text" : "Увімкнути повнотекстовий",
-    "Disable full text" : "Вимкнути повнотекстовий",
+    "Enable full text" : "Увімкнути контекстний",
+    "Disable full text" : "Вимкнути контекстний",
     "Delete" : "Вилучити",
     "Dismiss" : "Припинити",
     "Collapse" : "Згорнути",
