@@ -205,7 +205,7 @@
                     <span ng-if="!item.sharedBy" class="source"><?php p($l->t('from')) ?>
                         <a ng-href="#/items/feeds/{{ ::item.feedId }}/">
                             {{ ::Content.getFeed(item.feedId).title }}
-                            <img ng-if="Content.getFeed(item.feedId).faviconLink && !Content.isCompactView()" src="{{ ::Content.getFeed(item.feedId).faviconLink }}" alt="favicon">
+                            <img ng-if="Content.getFeed(item.feedId).faviconLink && !Content.isCompactView()" ng-src="{{ ::Content.getFeed(item.feedId).faviconLink }}" alt="favicon">
                         </a>
                     </span>
                     <span ng-if="item.sharedBy">
